@@ -16,9 +16,9 @@
 # limitations under the License.
 #
 
-require "chef_zero/data_store/data_already_exists_error"
-require "chef_zero/data_store/data_not_found_error"
-require "chef_zero/data_store/interface_v2"
+require_relative "data_already_exists_error"
+require_relative "data_not_found_error"
+require_relative "interface_v2"
 require "fileutils"
 
 module ChefZero
@@ -44,6 +44,7 @@ module ChefZero
         if destructible
           Dir.entries(root).each do |entry|
             next if entry == "." || entry == ".."
+
             FileUtils.rm_rf(Path.join(root, entry))
           end
         end
@@ -69,7 +70,7 @@ module ChefZero
           FileUtils.mkdir_p(path_to(path))
         end
         begin
-          File.open(path_to(path, name), File::WRONLY | File::CREAT | File::EXCL | File::BINARY, :internal_encoding => nil) do |file|
+          File.open(path_to(path, name), File::WRONLY | File::CREAT | File::EXCL | File::BINARY, internal_encoding: nil) do |file|
             file.write data
           end
         rescue Errno::ENOENT
@@ -80,11 +81,9 @@ module ChefZero
       end
 
       def get(path, request = nil)
-        begin
-          return IO.read(path_to(path))
-        rescue Errno::ENOENT
-          raise DataNotFoundError.new(path)
-        end
+        IO.read(path_to(path))
+      rescue Errno::ENOENT
+        raise DataNotFoundError.new(path)
       end
 
       def set(path, data, *options)
@@ -96,7 +95,7 @@ module ChefZero
           if options.include?(:create)
             mode |= File::CREAT
           end
-          File.open(path_to(path), mode, :internal_encoding => nil) do |file|
+          File.open(path_to(path), mode, internal_encoding: nil) do |file|
             file.write data
           end
         rescue Errno::ENOENT
@@ -105,18 +104,17 @@ module ChefZero
       end
 
       def delete(path)
-        begin
-          File.delete(path_to(path))
-        rescue Errno::ENOENT
-          raise DataNotFoundError.new(path)
-        end
+        File.delete(path_to(path))
+      rescue Errno::ENOENT
+        raise DataNotFoundError.new(path)
       end
 
       def delete_dir(path, *options)
         if options.include?(:recursive)
-          if !File.exist?(path_to(path))
+          unless File.exist?(path_to(path))
             raise DataNotFoundError.new(path)
           end
+
           FileUtils.rm_rf(path_to(path))
         else
           begin
@@ -128,19 +126,17 @@ module ChefZero
       end
 
       def list(path)
-        begin
-          Dir.entries(path_to(path)).select { |entry| entry != "." && entry != ".." }.to_a
-        rescue Errno::ENOENT
-          raise DataNotFoundError.new(path)
-        end
+        Dir.entries(path_to(path)).select { |entry| entry != "." && entry != ".." }.to_a
+      rescue Errno::ENOENT
+        raise DataNotFoundError.new(path)
       end
 
       def exists?(path, options = {})
-        File.exists?(path_to(path))
+        File.exist?(path_to(path))
       end
 
       def exists_dir?(path)
-        File.exists?(path_to(path))
+        File.exist?(path_to(path))
       end
     end
   end
