@@ -16,7 +16,7 @@
 # limitations under the License.
 #
 
-require "chef_zero/data_store/interface_v1"
+require_relative "interface_v1"
 
 module ChefZero
   module DataStore
@@ -90,13 +90,11 @@ module ChefZero
       protected
 
       def fix_exceptions
-        begin
-          yield
-        rescue DataAlreadyExistsError => e
-          raise DataAlreadyExistsError.new(e.path[2..-1], e)
-        rescue DataNotFoundError => e
-          raise DataNotFoundError.new(e.path[2..-1], e)
-        end
+        yield
+      rescue DataAlreadyExistsError => e
+        raise DataAlreadyExistsError.new(e.path[2..-1], e)
+      rescue DataNotFoundError => e
+        raise DataNotFoundError.new(e.path[2..-1], e)
       end
 
       def fix_path(path)
