@@ -1,6 +1,6 @@
 require "ffi_yajl"
-require "chef_zero/rest_base"
-require "chef_zero/chef_data/acl_path"
+require_relative "../rest_base"
+require_relative "../chef_data/acl_path"
 
 module ChefZero
   module Endpoints
@@ -23,6 +23,7 @@ module ChefZero
         if !acl_path || !%w{read create update delete grant}.include?(perm)
           raise RestErrorResponse.new(404, "Object not found: #{build_uri(request.base_uri, request.rest_path)}")
         end
+
         [acl_path, perm]
       end
 
@@ -30,8 +31,8 @@ module ChefZero
         path, perm = validate_request(request)
         acls = FFI_Yajl::Parser.parse(get_data(request, path))
         acls[perm] = FFI_Yajl::Parser.parse(request.body)[perm]
-        set_data(request, path, FFI_Yajl::Encoder.encode(acls, :pretty => true))
-        json_response(200, { "uri" => "#{build_uri(request.base_uri, request.rest_path)}" })
+        set_data(request, path, FFI_Yajl::Encoder.encode(acls, pretty: true))
+        json_response(200, { "uri" => (build_uri(request.base_uri, request.rest_path)).to_s })
       end
     end
   end
