@@ -1,6 +1,6 @@
 require "ffi_yajl"
-require "chef_zero/endpoints/rest_object_endpoint"
-require "chef_zero/chef_data/data_normalizer"
+require_relative "rest_object_endpoint"
+require_relative "../chef_data/data_normalizer"
 
 module ChefZero
   module Endpoints
@@ -15,7 +15,7 @@ module ChefZero
       def populate_defaults(request, response_json)
         container = FFI_Yajl::Parser.parse(response_json)
         container = ChefData::DataNormalizer.normalize_container(container, request.rest_path[3])
-        FFI_Yajl::Encoder.encode(container, :pretty => true)
+        FFI_Yajl::Encoder.encode(container, pretty: true)
       end
     end
   end
