@@ -1,8 +1,8 @@
 require "ffi_yajl"
-require "chef_zero/endpoints/rest_object_endpoint"
-require "chef_zero/rest_error_response"
-require "chef_zero/chef_data/data_normalizer"
-require "chef_zero/data_store/data_not_found_error"
+require_relative "rest_object_endpoint"
+require_relative "../rest_error_response"
+require_relative "../chef_data/data_normalizer"
+require_relative "../data_store/data_not_found_error"
 
 module ChefZero
   module Endpoints
@@ -27,11 +27,12 @@ module ChefZero
             if request.query_params["force"] != "true"
               raise RestErrorResponse.new(409, "The cookbook #{name} at version #{version} is frozen. Use the 'force' option to override.")
             end
+
             # For some reason, you are forever unable to modify "frozen?" on a frozen cookbook.
             request_body = FFI_Yajl::Parser.parse(request.body)
-            if !request_body["frozen?"]
+            unless request_body["frozen?"]
               request_body["frozen?"] = true
-              request.body = FFI_Yajl::Encoder.encode(request_body, :pretty => true)
+              request.body = FFI_Yajl::Encoder.encode(request_body, pretty: true)
             end
           end
         end
@@ -74,7 +75,7 @@ module ChefZero
         FFI_Yajl::Parser.parse(cookbook).each_pair do |key, value|
           if value.is_a?(Array)
             value.each do |file|
-              if file.is_a?(Hash) && file.has_key?("checksum")
+              if file.is_a?(Hash) && file.key?("checksum")
                 result << file["checksum"]
               end
             end
@@ -92,6 +93,7 @@ module ChefZero
           rescue ChefZero::DataStore::DataNotFoundError
             # Not all chef versions support cookbook_artifacts
             raise unless cookbook_type == "cookbook_artifacts"
+
             cookbooks = []
           end
           cookbooks.each do |cookbook_name|
@@ -99,7 +101,7 @@ module ChefZero
             begin
               data_store.list(request.rest_path[0..1] + [cookbook_type, cookbook_name]).each do |version|
                 cookbook = data_store.get(request.rest_path[0..1] + [cookbook_type, cookbook_name, version], request)
-                deleted_checksums = deleted_checksums - get_checksums(cookbook)
+                deleted_checksums -= get_checksums(cookbook)
               end
             rescue ChefZero::DataStore::DataNotFoundError
             end
@@ -122,7 +124,7 @@ module ChefZero
         cookbook["chef_type"] ||= "cookbook_version"
         cookbook["json_class"] ||= "Chef::CookbookVersion"
         cookbook = ChefData::DataNormalizer.normalize_cookbook(self, request.rest_path[0..1], cookbook, request.rest_path[3], request.rest_path[4], request.base_uri, request.method, false, api_version: request.api_version) if normalize
-        FFI_Yajl::Encoder.encode(cookbook, :pretty => true)
+        FFI_Yajl::Encoder.encode(cookbook, pretty: true)
       end
 
       def latest_version(versions)
