@@ -1,7 +1,7 @@
 require "ffi_yajl"
-require "chef_zero/endpoints/rest_object_endpoint"
-require "chef_zero/endpoints/data_bag_item_endpoint"
-require "chef_zero/chef_data/data_normalizer"
+require_relative "rest_object_endpoint"
+require_relative "data_bag_item_endpoint"
+require_relative "../chef_data/data_normalizer"
 
 module ChefZero
   module Endpoints
@@ -18,7 +18,7 @@ module ChefZero
       def self.populate_defaults(request, response_json, data_bag, data_bag_item)
         response = FFI_Yajl::Parser.parse(response_json)
         response = ChefData::DataNormalizer.normalize_data_bag_item(response, data_bag, data_bag_item, request.method)
-        FFI_Yajl::Encoder.encode(response, :pretty => true)
+        FFI_Yajl::Encoder.encode(response, pretty: true)
       end
     end
   end
