@@ -1,5 +1,5 @@
 require "ffi_yajl"
-require "chef_zero/endpoints/cookbooks_base"
+require_relative "cookbooks_base"
 
 module ChefZero
   module Endpoints
