@@ -1,6 +1,6 @@
 require "ffi_yajl"
-require "chef_zero/endpoints/rest_object_endpoint"
-require "chef_zero/chef_data/data_normalizer"
+require_relative "rest_object_endpoint"
+require_relative "../chef_data/data_normalizer"
 
 module ChefZero
   module Endpoints
@@ -13,7 +13,7 @@ module ChefZero
       def populate_defaults(request, response_json)
         group = FFI_Yajl::Parser.parse(response_json)
         group = ChefData::DataNormalizer.normalize_group(group, request.rest_path[3], request.rest_path[1])
-        FFI_Yajl::Encoder.encode(group, :pretty => true)
+        FFI_Yajl::Encoder.encode(group, pretty: true)
       end
     end
   end
