@@ -1,6 +1,6 @@
 require "ffi_yajl"
-require "chef_zero/endpoints/rest_object_endpoint"
-require "chef_zero/chef_data/data_normalizer"
+require_relative "rest_object_endpoint"
+require_relative "../chef_data/data_normalizer"
 
 module ChefZero
   module Endpoints
@@ -9,12 +9,12 @@ module ChefZero
       def put(request)
         data = parse_json(request.body)
 
-        if data.has_key?("policy_name") && policy_name_invalid?(data["policy_name"])
-          return error(400, "Field 'policy_name' invalid", :pretty => false)
+        if data.key?("policy_name") && policy_name_invalid?(data["policy_name"])
+          return error(400, "Field 'policy_name' invalid", pretty: false)
         end
 
-        if data.has_key?("policy_group") && policy_name_invalid?(data["policy_group"])
-          return error(400, "Field 'policy_group' invalid", :pretty => false)
+        if data.key?("policy_group") && policy_name_invalid?(data["policy_group"])
+          return error(400, "Field 'policy_group' invalid", pretty: false)
         end
 
         super(request)
@@ -27,7 +27,7 @@ module ChefZero
       def populate_defaults(request, response_json)
         node = FFI_Yajl::Parser.parse(response_json)
         node = ChefData::DataNormalizer.normalize_node(node, request.rest_path[3])
-        FFI_Yajl::Encoder.encode(node, :pretty => true)
+        FFI_Yajl::Encoder.encode(node, pretty: true)
       end
     end
   end
