@@ -1,5 +1,5 @@
 require "ffi_yajl"
-require "chef_zero/rest_base"
+require_relative "../rest_base"
 
 module ChefZero
   module Endpoints
@@ -11,9 +11,9 @@ module ChefZero
         if id !~ /(.+)-#{orgname}$/
           raise HttpErrorResponse.new(404, "Invalid ID #{id}.  Must be of the form username-#{orgname}")
         end
+
         username = $1
         path = request.rest_path[0..-2] + [username]
-        data = FFI_Yajl::Parser.parse(get_data(request, path))
         delete_data(request, path)
         json_response(200, { "id" => id, "username" => username })
       end
