@@ -1,5 +1,5 @@
 require "ffi_yajl"
-require "chef_zero/rest_base"
+require_relative "../rest_base"
 
 module ChefZero
   module Endpoints
@@ -16,14 +16,15 @@ module ChefZero
         new_org.each do |key, value|
           org[key] = value
         end
-        save_org = FFI_Yajl::Encoder.encode(org, :pretty => true)
+        save_org = FFI_Yajl::Encoder.encode(org, pretty: true)
         if new_org["name"] != request.rest_path[-1]
           # This is a rename
-          return error(400, "Cannot rename org #{request.rest_path[-1]} to #{new_org['name']}: rename not supported for orgs")
+          return error(400, "Cannot rename org #{request.rest_path[-1]} to #{new_org["name"]}: rename not supported for orgs")
         end
+
         set_data(request, request.rest_path + [ "org" ], save_org)
         json_response(200, {
-          "uri" => "#{build_uri(request.base_uri, request.rest_path)}",
+          "uri" => (build_uri(request.base_uri, request.rest_path)).to_s,
           "name" => org["name"],
           "org_type" => org["org_type"],
           "full_name" => org["full_name"],
@@ -39,7 +40,7 @@ module ChefZero
       def populate_defaults(request, response_json)
         org = FFI_Yajl::Parser.parse(response_json)
         org = ChefData::DataNormalizer.normalize_organization(org, request.rest_path[1])
-        FFI_Yajl::Encoder.encode(org, :pretty => true)
+        FFI_Yajl::Encoder.encode(org, pretty: true)
       end
     end
   end
