@@ -1,5 +1,5 @@
 require "ffi_yajl"
-require "chef_zero/rest_base"
+require_relative "../rest_base"
 
 module ChefZero
   module Endpoints
@@ -17,7 +17,7 @@ module ChefZero
         # Get the result
         result_hash = {}
         list_data(request).sort.each do |name|
-          result_hash[name] = "#{build_uri(request.base_uri, request.rest_path + [name])}"
+          result_hash[name] = (build_uri(request.base_uri, request.rest_path + [name])).to_s
         end
         json_response(200, result_hash)
       end
@@ -26,10 +26,10 @@ module ChefZero
         contents = request.body
         key = get_key(contents)
         if key.nil?
-          error(400, "Must specify #{identity_keys.map { |k| k.inspect }.join(' or ')} in JSON")
+          error(400, "Must specify #{identity_keys.map(&:inspect).join(" or ")} in JSON")
         else
           create_data(request, request.rest_path, key, contents)
-          json_response(201, { "uri" => "#{build_uri(request.base_uri, request.rest_path + [key])}" })
+          json_response(201, { "uri" => (build_uri(request.base_uri, request.rest_path + [key])).to_s })
         end
       end
 
