@@ -1,6 +1,6 @@
 require "ffi_yajl"
-require "chef_zero/rest_base"
-require "chef_zero/rest_error_response"
+require_relative "../rest_base"
+require_relative "../rest_error_response"
 
 module ChefZero
   module Endpoints
@@ -20,7 +20,7 @@ module ChefZero
 
       def put(request)
         # We grab the old body to trigger a 404 if it doesn't exist
-        old_body = get_data(request)
+        get_data(request)
 
         # If it's a rename, check for conflict and delete the old value
         if is_rename?(request)
@@ -52,7 +52,7 @@ module ChefZero
           existing_json = FFI_Yajl::Parser.parse(existing_value)
           merged_json = existing_json.merge(request_json)
           if merged_json.size > request_json.size
-            return FFI_Yajl::Encoder.encode(merged_json, :pretty => true)
+            return FFI_Yajl::Encoder.encode(merged_json, pretty: true)
           end
         end
 
@@ -69,7 +69,8 @@ module ChefZero
 
       # Does this request change the value of the identity key?
       def is_rename?(request)
-        return false unless key = identity_key_value(request)
+        return false unless (key = identity_key_value(request))
+
         key != request.rest_path[-1]
       end
     end
