@@ -1,6 +1,6 @@
 require "ffi_yajl"
-require "chef_zero/endpoints/rest_object_endpoint"
-require "chef_zero/chef_data/data_normalizer"
+require_relative "rest_object_endpoint"
+require_relative "../chef_data/data_normalizer"
 
 module ChefZero
   module Endpoints
@@ -9,7 +9,7 @@ module ChefZero
       def populate_defaults(request, response_json)
         role = FFI_Yajl::Parser.parse(response_json)
         role = ChefData::DataNormalizer.normalize_role(role, request.rest_path[3])
-        FFI_Yajl::Encoder.encode(role, :pretty => true)
+        FFI_Yajl::Encoder.encode(role, pretty: true)
       end
     end
   end
