@@ -1,5 +1,5 @@
 require "ffi_yajl"
-require "chef_zero/rest_base"
+require_relative "../rest_base"
 
 module ChefZero
   module Endpoints
@@ -10,13 +10,13 @@ module ChefZero
         name = request_json["username"]
         password = request_json["password"]
         user = get_data(request, request.rest_path[0..-2] + ["users", name], :nil)
-        if !user
+        unless user
           raise RestErrorResponse.new(403, "Nonexistent user")
         end
 
         user = FFI_Yajl::Parser.parse(user)
         user = ChefData::DataNormalizer.normalize_user(user, name, [ "username" ], server.options[:osc_compat])
-        if !user["recovery_authentication_enabled"]
+        unless user["recovery_authentication_enabled"]
           raise RestErrorResponse.new(403, "Only users with recovery_authentication_enabled=true may use /system_recovery to log in")
         end
         if user["password"] != password
