@@ -1,6 +1,6 @@
 require "ffi_yajl"
-require "chef_zero/endpoints/rest_object_endpoint"
-require "chef_zero/chef_data/data_normalizer"
+require_relative "rest_object_endpoint"
+require_relative "../chef_data/data_normalizer"
 
 module ChefZero
   module Endpoints
