@@ -1,5 +1,5 @@
 require "ffi_yajl"
-require "chef_zero/rest_base"
+require_relative "../rest_base"
 
 module ChefZero
   module Endpoints
@@ -11,6 +11,7 @@ module ChefZero
         if id !~ /^#{username}-(.+)/
           raise RestErrorResponse.new(400, "Association request #{id} is invalid.  Must be #{username}-orgname.")
         end
+
         orgname = $1
 
         json = FFI_Yajl::Parser.parse(request.body)
@@ -26,7 +27,7 @@ module ChefZero
           if !users["users"] || !users["users"].include?(username)
             users["users"] ||= []
             users["users"] |= [ username ]
-            set_data(request, [ "organizations", orgname, "groups", "users" ], FFI_Yajl::Encoder.encode(users, :pretty => true))
+            set_data(request, [ "organizations", orgname, "groups", "users" ], FFI_Yajl::Encoder.encode(users, pretty: true))
           end
         elsif json["response"] == "reject"
           delete_data(request, association_request_path)
