@@ -1,7 +1,7 @@
-require "chef_zero/rest_request"
-require "chef_zero/rest_error_response"
-require "chef_zero/data_store/data_not_found_error"
-require "chef_zero/chef_data/acl_path"
+require_relative "rest_request"
+require_relative "rest_error_response"
+require_relative "data_store/data_not_found_error"
+require_relative "chef_data/acl_path"
 
 module ChefZero
   class RestBase
@@ -30,15 +30,13 @@ module ChefZero
         }
 
         return json_response(406,
-                             response,
-                             request_version: version, response_version: -1
-                            )
+          response,
+          request_version: version, response_version: -1)
       end
     rescue ArgumentError
-      return json_response(406,
-                           { "username" => request.requestor },
-                           request_version: -1, response_version: -1
-                          )
+      json_response(406,
+        { "username" => request.requestor },
+        request_version: -1, response_version: -1)
     end
 
     def call(request)
@@ -46,17 +44,18 @@ module ChefZero
       return response unless response.nil?
 
       method = request.method.downcase.to_sym
-      if !self.respond_to?(method)
-        accept_methods = [:get, :put, :post, :delete].select { |m| self.respond_to?(m) }
+      unless respond_to?(method)
+        accept_methods = %i{get put post delete}.select { |m| respond_to?(m) }
         accept_methods_str = accept_methods.map { |m| m.to_s.upcase }.join(", ")
-        return [405, { "Content-Type" => "text/plain", "Allow" => accept_methods_str }, "Bad request method for '#{request.env['REQUEST_PATH']}': #{request.env['REQUEST_METHOD']}"]
+        return [405, { "Content-Type" => "text/plain", "Allow" => accept_methods_str }, "Bad request method for '#{request.env["REQUEST_PATH"]}': #{request.env["REQUEST_METHOD"]}"]
       end
       if json_only && !accepts?(request, "application", "json")
         return [406, { "Content-Type" => "text/plain" }, "Must accept application/json"]
       end
+
       # Dispatch to get()/post()/put()/delete()
       begin
-        self.send(method, request)
+        send(method, request)
       rescue RestErrorResponse => e
         ChefZero::Log.debug("#{e.inspect}\n#{e.backtrace.join("\n")}")
         error(e.response_code, e.error)
@@ -70,14 +69,15 @@ module ChefZero
     def accepts?(request, category, type)
       # If HTTP_ACCEPT is not sent at all, assume it accepts anything
       # This parses as per http://tools.ietf.org/html/rfc7231#section-5.3
-      return true if !request.env["HTTP_ACCEPT"]
+      return true unless request.env["HTTP_ACCEPT"]
+
       accepts = request.env["HTTP_ACCEPT"].split(/,\s*/).map { |x| x.split(";", 2)[0].strip }
-      return accepts.include?("#{category}/#{type}") || accepts.include?("#{category}/*") || accepts.include?("*/*")
+      accepts.include?("#{category}/#{type}") || accepts.include?("#{category}/*") || accepts.include?("*/*")
     end
 
     def get_data(request, rest_path = nil, *options)
       rest_path ||= request.rest_path
-      rest_path = rest_path.map { |v| URI.decode(v) }
+      rest_path = rest_path.map { |v| self.class.rfc2396_parser.unescape(v) }
       begin
         data_store.get(rest_path, request)
       rescue DataStore::DataNotFoundError
@@ -145,7 +145,7 @@ module ChefZero
     def set_data(request, rest_path, data, *options)
       rest_path ||= request.rest_path
       begin
-        data_store.set(rest_path, data, *options, :requestor => request.requestor)
+        data_store.set(rest_path, data, *options, requestor: request.requestor)
       rescue DataStore::DataNotFoundError
         if options.include?(:data_store_exceptions)
           raise
@@ -158,7 +158,7 @@ module ChefZero
     def create_data_dir(request, rest_path, name, *options)
       rest_path ||= request.rest_path
       begin
-        data_store.create_dir(rest_path, name, *options, :requestor => request.requestor)
+        data_store.create_dir(rest_path, name, *options, requestor: request.requestor)
       rescue DataStore::DataNotFoundError
         if options.include?(:data_store_exceptions)
           raise
@@ -177,7 +177,7 @@ module ChefZero
     def create_data(request, rest_path, name, data, *options)
       rest_path ||= request.rest_path
       begin
-        data_store.create(rest_path, name, data, *options, :requestor => request.requestor)
+        data_store.create(rest_path, name, data, *options, requestor: request.requestor)
       rescue DataStore::DataNotFoundError
         if options.include?(:data_store_exceptions)
           raise
@@ -284,7 +284,7 @@ module ChefZero
     end
 
     def self.build_uri(base_uri, rest_path)
-      "#{base_uri}/#{rest_path.map { |v| URI.escape(v) }.join('/')}"
+      "#{base_uri}/#{rest_path.map { |v| rfc2396_parser.escape(v) }.join("/")}"
     end
 
     def populate_defaults(request, response)
@@ -296,7 +296,7 @@ module ChefZero
     end
 
     def to_json(data)
-      FFI_Yajl::Encoder.encode(data, :pretty => true)
+      FFI_Yajl::Encoder.encode(data, pretty: true)
     end
 
     def get_data_or_else(request, path, or_else_value)
@@ -324,5 +324,9 @@ module ChefZero
         name.size > 255 ||
         name =~ /[+ !]/
     end
+
+    def self.rfc2396_parser
+      @parser ||= URI::RFC2396_Parser.new
+    end
   end
 end
