@@ -1,11 +1,11 @@
 module ChefZero
   class RestErrorResponse < StandardError
+    attr_reader :response_code, :error
+
     def initialize(response_code, error)
       @response_code = response_code
       @error = error
+      super "#{response_code}: #{error}"
     end
-
-    attr_reader :response_code
-    attr_reader :error
   end
 end
