@@ -1,6 +1,6 @@
 require "tempfile"
-require "chef_zero/server"
-require "chef_zero/rest_request"
+require_relative "server"
+require_relative "rest_request"
 
 module ChefZero
   module RSpec
@@ -42,12 +42,13 @@ module ChefZero
     extend RSpecClassMethods
 
     def when_the_chef_server(description, *tags, &block)
-      context "When the Chef server #{description}", *tags do
+      context "When the #{ChefZero::Dist::PRODUCT} server #{description}", *tags do
         extend WhenTheChefServerClassMethods
         include WhenTheChefServerInstanceMethods
 
         # Take the passed-in options
 
+        # rubocop:disable Lint/UnderscorePrefixedVariableName
         define_singleton_method(:chef_server_options) do
           @chef_server_options ||= begin
             _chef_server_options = { port: 8900, signals: false, log_requests: true }
@@ -55,11 +56,12 @@ module ChefZero
             _chef_server_options = _chef_server_options.freeze
           end
         end
+        # rubocop:enable Lint/UnderscorePrefixedVariableName
 
         # Merge in chef_server_options from let(:chef_server_options)
-        def chef_server_options
+        def chef_server_options # rubocop:disable Lint/NestedMethodDefinition
           chef_server_options = self.class.chef_server_options.dup
-          chef_server_options = chef_server_options.merge(chef_zero_opts) if self.respond_to?(:chef_zero_opts)
+          chef_server_options = chef_server_options.merge(chef_zero_opts) if respond_to?(:chef_zero_opts)
           chef_server_options
         end
 
@@ -67,7 +69,8 @@ module ChefZero
           if chef_server_options[:server_scope] != self.class.chef_server_options[:server_scope]
             raise "server_scope: #{chef_server_options[:server_scope]} will not be honored: it can only be set on when_the_chef_server!"
           end
-          Log.info("Starting Chef server with options #{chef_server_options}")
+
+          Log.info("Starting #{ChefZero::Dist::PRODUCT} server with options #{chef_server_options}")
 
           ChefZero::RSpec.set_server_options(chef_server_options)
 
@@ -217,7 +220,7 @@ module ChefZero
         with_object_path("cookbooks/#{name}") do
           # If you didn't specify metadata.rb, we generate it for you. If you
           # explicitly set it to nil, that means you don't want it at all.
-          if data.has_key?("metadata.rb")
+          if data.key?("metadata.rb")
             if data["metadata.rb"].nil?
               data.delete("metadata.rb")
             end
@@ -233,7 +236,7 @@ module ChefZero
         with_object_path("cookbook_artifacts/#{name}") do
           # If you didn't specify metadata.rb, we generate it for you. If you
           # explicitly set it to nil, that means you don't want it at all.
-          if data.has_key?("metadata.rb")
+          if data.key?("metadata.rb")
             if data["metadata.rb"].nil?
               data.delete("metadata.rb")
             end
@@ -331,7 +334,7 @@ module ChefZero
         if data.is_a?(String)
           data
         else
-          FFI_Yajl::Encoder.encode(data, :pretty => true)
+          FFI_Yajl::Encoder.encode(data, pretty: true)
         end
       end
 
