@@ -26,109 +26,110 @@ require "rack"
 require "webrick"
 require "webrick/https"
 
-require "chef_zero"
-require "chef_zero/socketless_server_map"
-require "chef_zero/chef_data/cookbook_data"
-require "chef_zero/chef_data/acl_path"
-require "chef_zero/rest_router"
-require "chef_zero/data_store/memory_store_v2"
-require "chef_zero/data_store/v1_to_v2_adapter"
-require "chef_zero/data_store/default_facade"
-require "chef_zero/version"
+require_relative "../chef_zero"
+require_relative "socketless_server_map"
+require_relative "chef_data/cookbook_data"
+require_relative "chef_data/acl_path"
+require_relative "rest_router"
+require_relative "data_store/memory_store_v2"
+require_relative "data_store/v1_to_v2_adapter"
+require_relative "data_store/default_facade"
+require_relative "version"
+require "chef_zero/dist.rb"
 
-require "chef_zero/endpoints/rest_list_endpoint"
-require "chef_zero/endpoints/authenticate_user_endpoint"
-require "chef_zero/endpoints/acls_endpoint"
-require "chef_zero/endpoints/acl_endpoint"
-require "chef_zero/endpoints/actor_endpoint"
-require "chef_zero/endpoints/actors_endpoint"
-require "chef_zero/endpoints/actor_key_endpoint"
-require "chef_zero/endpoints/organization_user_key_endpoint"
-require "chef_zero/endpoints/organization_user_default_key_endpoint"
-require "chef_zero/endpoints/organization_user_keys_endpoint"
-require "chef_zero/endpoints/actor_default_key_endpoint"
-require "chef_zero/endpoints/actor_keys_endpoint"
-require "chef_zero/endpoints/cookbooks_endpoint"
-require "chef_zero/endpoints/cookbook_endpoint"
-require "chef_zero/endpoints/cookbook_version_endpoint"
-require "chef_zero/endpoints/cookbook_artifacts_endpoint"
-require "chef_zero/endpoints/cookbook_artifact_endpoint"
-require "chef_zero/endpoints/cookbook_artifact_identifier_endpoint"
-require "chef_zero/endpoints/containers_endpoint"
-require "chef_zero/endpoints/container_endpoint"
-require "chef_zero/endpoints/controls_endpoint"
-require "chef_zero/endpoints/dummy_endpoint"
-require "chef_zero/endpoints/data_bags_endpoint"
-require "chef_zero/endpoints/data_bag_endpoint"
-require "chef_zero/endpoints/data_bag_item_endpoint"
-require "chef_zero/endpoints/groups_endpoint"
-require "chef_zero/endpoints/group_endpoint"
-require "chef_zero/endpoints/environment_endpoint"
-require "chef_zero/endpoints/environment_cookbooks_endpoint"
-require "chef_zero/endpoints/environment_cookbook_endpoint"
-require "chef_zero/endpoints/environment_cookbook_versions_endpoint"
-require "chef_zero/endpoints/environment_nodes_endpoint"
-require "chef_zero/endpoints/environment_recipes_endpoint"
-require "chef_zero/endpoints/environment_role_endpoint"
-require "chef_zero/endpoints/license_endpoint"
-require "chef_zero/endpoints/node_endpoint"
-require "chef_zero/endpoints/nodes_endpoint"
-require "chef_zero/endpoints/node_identifiers_endpoint"
-require "chef_zero/endpoints/organizations_endpoint"
-require "chef_zero/endpoints/organization_endpoint"
-require "chef_zero/endpoints/organization_association_requests_endpoint"
-require "chef_zero/endpoints/organization_association_request_endpoint"
-require "chef_zero/endpoints/organization_authenticate_user_endpoint"
-require "chef_zero/endpoints/organization_users_endpoint"
-require "chef_zero/endpoints/organization_user_endpoint"
-require "chef_zero/endpoints/organization_validator_key_endpoint"
-require "chef_zero/endpoints/policies_endpoint"
-require "chef_zero/endpoints/policy_endpoint"
-require "chef_zero/endpoints/policy_revisions_endpoint"
-require "chef_zero/endpoints/policy_revision_endpoint"
-require "chef_zero/endpoints/policy_groups_endpoint"
-require "chef_zero/endpoints/policy_group_endpoint"
-require "chef_zero/endpoints/policy_group_policy_endpoint"
-require "chef_zero/endpoints/principal_endpoint"
-require "chef_zero/endpoints/role_endpoint"
-require "chef_zero/endpoints/role_environments_endpoint"
-require "chef_zero/endpoints/sandboxes_endpoint"
-require "chef_zero/endpoints/sandbox_endpoint"
-require "chef_zero/endpoints/searches_endpoint"
-require "chef_zero/endpoints/search_endpoint"
-require "chef_zero/endpoints/system_recovery_endpoint"
-require "chef_zero/endpoints/user_association_requests_endpoint"
-require "chef_zero/endpoints/user_association_requests_count_endpoint"
-require "chef_zero/endpoints/user_association_request_endpoint"
-require "chef_zero/endpoints/user_organizations_endpoint"
-require "chef_zero/endpoints/file_store_file_endpoint"
-require "chef_zero/endpoints/not_found_endpoint"
-require "chef_zero/endpoints/version_endpoint"
-require "chef_zero/endpoints/server_api_version_endpoint"
-require "chef_zero/endpoints/universe_endpoint"
+require_relative "endpoints/rest_list_endpoint"
+require_relative "endpoints/authenticate_user_endpoint"
+require_relative "endpoints/acls_endpoint"
+require_relative "endpoints/acl_endpoint"
+require_relative "endpoints/actor_endpoint"
+require_relative "endpoints/actors_endpoint"
+require_relative "endpoints/actor_key_endpoint"
+require_relative "endpoints/organization_user_key_endpoint"
+require_relative "endpoints/organization_user_default_key_endpoint"
+require_relative "endpoints/organization_user_keys_endpoint"
+require_relative "endpoints/actor_default_key_endpoint"
+require_relative "endpoints/actor_keys_endpoint"
+require_relative "endpoints/cookbooks_endpoint"
+require_relative "endpoints/cookbook_endpoint"
+require_relative "endpoints/cookbook_version_endpoint"
+require_relative "endpoints/cookbook_artifacts_endpoint"
+require_relative "endpoints/cookbook_artifact_endpoint"
+require_relative "endpoints/cookbook_artifact_identifier_endpoint"
+require_relative "endpoints/containers_endpoint"
+require_relative "endpoints/container_endpoint"
+require_relative "endpoints/controls_endpoint"
+require_relative "endpoints/dummy_endpoint"
+require_relative "endpoints/data_bags_endpoint"
+require_relative "endpoints/data_bag_endpoint"
+require_relative "endpoints/data_bag_item_endpoint"
+require_relative "endpoints/groups_endpoint"
+require_relative "endpoints/group_endpoint"
+require_relative "endpoints/environment_endpoint"
+require_relative "endpoints/environment_cookbooks_endpoint"
+require_relative "endpoints/environment_cookbook_endpoint"
+require_relative "endpoints/environment_cookbook_versions_endpoint"
+require_relative "endpoints/environment_nodes_endpoint"
+require_relative "endpoints/environment_recipes_endpoint"
+require_relative "endpoints/environment_role_endpoint"
+require_relative "endpoints/license_endpoint"
+require_relative "endpoints/node_endpoint"
+require_relative "endpoints/nodes_endpoint"
+require_relative "endpoints/node_identifiers_endpoint"
+require_relative "endpoints/organizations_endpoint"
+require_relative "endpoints/organization_endpoint"
+require_relative "endpoints/organization_association_requests_endpoint"
+require_relative "endpoints/organization_association_request_endpoint"
+require_relative "endpoints/organization_authenticate_user_endpoint"
+require_relative "endpoints/organization_users_endpoint"
+require_relative "endpoints/organization_user_endpoint"
+require_relative "endpoints/organization_validator_key_endpoint"
+require_relative "endpoints/policies_endpoint"
+require_relative "endpoints/policy_endpoint"
+require_relative "endpoints/policy_revisions_endpoint"
+require_relative "endpoints/policy_revision_endpoint"
+require_relative "endpoints/policy_groups_endpoint"
+require_relative "endpoints/policy_group_endpoint"
+require_relative "endpoints/policy_group_policy_endpoint"
+require_relative "endpoints/principal_endpoint"
+require_relative "endpoints/role_endpoint"
+require_relative "endpoints/role_environments_endpoint"
+require_relative "endpoints/sandboxes_endpoint"
+require_relative "endpoints/sandbox_endpoint"
+require_relative "endpoints/searches_endpoint"
+require_relative "endpoints/search_endpoint"
+require_relative "endpoints/system_recovery_endpoint"
+require_relative "endpoints/user_association_requests_endpoint"
+require_relative "endpoints/user_association_requests_count_endpoint"
+require_relative "endpoints/user_association_request_endpoint"
+require_relative "endpoints/user_organizations_endpoint"
+require_relative "endpoints/file_store_file_endpoint"
+require_relative "endpoints/not_found_endpoint"
+require_relative "endpoints/version_endpoint"
+require_relative "endpoints/server_api_version_endpoint"
+require_relative "endpoints/universe_endpoint"
 
 module ChefZero
 
   class Server
 
     DEFAULT_OPTIONS = {
-      :host => ["127.0.0.1"],
-      :port => 8889,
-      :log_level => :warn,
-      :generate_real_keys => true,
-      :single_org => "chef",
-      :ssl => false,
+      host: ["127.0.0.1"],
+      port: 8889,
+      log_level: :warn,
+      generate_real_keys: true,
+      single_org: "chef",
+      ssl: false,
     }.freeze
 
     GLOBAL_ENDPOINTS = [
       "/license",
       "/version",
       "/server_api_version",
-    ]
+    ].freeze
 
     def initialize(options = {})
       @options = DEFAULT_OPTIONS.merge(options)
-      if @options[:single_org] && !@options.has_key?(:osc_compat)
+      if @options[:single_org] && !@options.key?(:osc_compat)
         @options[:osc_compat] = true
       end
       @options.freeze
@@ -175,7 +176,8 @@ module ChefZero
     end
 
     def local_mode_url
-      raise "Port not yet set, cannot generate URL" unless port.kind_of?(Integer)
+      raise "Port not yet set, cannot generate URL" unless port.is_a?(Integer)
+
       "chefzero://localhost:#{port}"
     end
 
@@ -231,7 +233,7 @@ module ChefZero
       if publish
         output = publish.respond_to?(:puts) ? publish : STDOUT
         output.puts <<-EOH.gsub(/^ {10}/, "")
-          >> Starting Chef Zero (v#{ChefZero::VERSION})...
+          >> Starting #{ChefZero::Dist::PRODUCT} (v#{ChefZero::VERSION})...
         EOH
       end
 
@@ -248,7 +250,7 @@ module ChefZero
 
       %w{INT TERM}.each do |signal|
         Signal.trap(signal) do
-          puts "\n>> Stopping Chef Zero..."
+          puts "\n>> Stopping #{ChefZero::Dist::PRODUCT}..."
           @server.shutdown
         end
       end
@@ -274,21 +276,21 @@ module ChefZero
       true
     rescue Errno::EADDRINUSE
       ChefZero::Log.warn("Port #{port} not available")
-      @server.listeners.each { |l| l.close }
+      @server.listeners.each(&:close)
       @server.listeners.clear
       false
     end
 
     def start_background(wait = 5)
       @server = WEBrick::HTTPServer.new(
-        :DoNotListen => true,
-        :AccessLog   => [],
-        :Logger      => WEBrick::Log.new(StringIO.new, 7),
-        :RequestTimeout => 300,
-        :SSLEnable => options[:ssl],
-        :SSLOptions => ssl_opts,
-        :SSLCertName => [ [ "CN", WEBrick::Utils.getservername ] ],
-        :StartCallback => proc do
+        DoNotListen: true,
+        AccessLog: [],
+        Logger: WEBrick::Log.new(StringIO.new, 7),
+        RequestTimeout: 300,
+        SSLEnable: options[:ssl],
+        SSLOptions: ssl_opts,
+        SSLCertName: [ [ "CN", WEBrick::Utils.getservername ] ],
+        StartCallback: proc do
           @running = true
         end
       )
@@ -304,7 +306,7 @@ module ChefZero
           break
         end
       end
-      if !@port
+      unless @port
         raise Errno::EADDRINUSE,
           "No port in :port range #{options[:port]} is available"
       end
@@ -362,7 +364,7 @@ module ChefZero
       end
     rescue Timeout::Error
       if @thread
-        ChefZero::Log.error("Chef Zero did not stop within #{wait} seconds! Killing...")
+        ChefZero::Log.error("#{ChefZero::Dist::PRODUCT} did not stop within #{wait} seconds! Killing...")
         @thread.kill
         SocketlessServerMap.deregister(port)
       end
@@ -484,7 +486,7 @@ module ChefZero
       if contents["policy_groups"]
         contents["policy_groups"].each_pair do |group_name, group|
           group["policies"].each do |policy_name, policy_revision|
-            data_store.set(["organizations", org_name, "policy_groups", group_name, "policies", policy_name], FFI_Yajl::Encoder.encode(policy_revision["revision_id"], :pretty => true), :create, :create_dir)
+            data_store.set(["organizations", org_name, "policy_groups", group_name, "policies", policy_name], FFI_Yajl::Encoder.encode(policy_revision["revision_id"], pretty: true), :create, :create_dir)
           end
         end
       end
@@ -493,18 +495,20 @@ module ChefZero
         if contents[cookbook_type]
           contents[cookbook_type].each_pair do |name_version, cookbook|
             if cookbook_type == "cookbook_artifacts"
-              name, dash, identifier = name_version.rpartition("-")
+              name, _, identifier = name_version.rpartition("-")
               cookbook_data = ChefData::CookbookData.to_hash(cookbook, name, identifier)
             elsif name_version =~ /(.+)-(\d+\.\d+\.\d+)$/
               cookbook_data = ChefData::CookbookData.to_hash(cookbook, $1, $2)
             else
               cookbook_data = ChefData::CookbookData.to_hash(cookbook, name_version)
             end
-            raise "No version specified" if !cookbook_data[:version]
+            raise "No version specified" unless cookbook_data[:version]
+
             data_store.create_dir(["organizations", org_name, cookbook_type], cookbook_data[:cookbook_name], :recursive)
-            data_store.set(["organizations", org_name, cookbook_type, cookbook_data[:cookbook_name], cookbook_data[:version]], FFI_Yajl::Encoder.encode(cookbook_data, :pretty => true), :create)
+            data_store.set(["organizations", org_name, cookbook_type, cookbook_data[:cookbook_name], cookbook_data[:version]], FFI_Yajl::Encoder.encode(cookbook_data, pretty: true), :create)
             cookbook_data.values.each do |files|
               next unless files.is_a? Array
+
               files.each do |file|
                 data_store.set(["organizations", org_name, "file_store", "checksums", file[:checksum]], get_file(cookbook, file[:path]), :create)
               end
@@ -641,6 +645,7 @@ module ChefZero
 
     def app
       return @app if @app
+
       router = RestRouter.new(endpoints)
       router.not_found = NotFoundEndpoint.new
 
@@ -699,7 +704,7 @@ module ChefZero
     end
 
     def dejsonize(value)
-      value.is_a?(Hash) ? FFI_Yajl::Encoder.encode(value, :pretty => true) : value
+      value.is_a?(Hash) ? FFI_Yajl::Encoder.encode(value, pretty: true) : value
     end
 
     def get_file(directory, path)
